@charset "UTF-8";
@import "entypo-fonts";

[class^="<%= Entypo.css_prefix %>-"], [class*=" <%= Entypo.css_prefix %>-"] {
  font-family: entypo;
  font-style: normal;
  font-weight: normal;
  display: inline-block;
  width: 1.1em;
  margin-right: .1em;
  text-align: center;
  -webkit-font-smoothing: antialiased;
}

/* main icon map */
.<%= Entypo.css_prefix %>-phone:before { content: '\1f4de'; } /* 1f4de */
.<%= Entypo.css_prefix %>-mobile:before { content: '\1f4f1'; } /* 1f4f1 */
.<%= Entypo.css_prefix %>-mouse:before { content: '\e789'; } /* e789 */
.<%= Entypo.css_prefix %>-address:before { content: '\e723'; } /* e723 */
.<%= Entypo.css_prefix %>-mail:before { content: '\2709'; } /* 2709 */
.<%= Entypo.css_prefix %>-paper-plane:before { content: '\e79b'; } /* e79b */
.<%= Entypo.css_prefix %>-pencil:before { content: '\270e'; } /* 270e */
.<%= Entypo.css_prefix %>-feather:before { content: '\2712'; } /* 2712 */
.<%= Entypo.css_prefix %>-attach:before { content: '\1f4ce'; } /* 1f4ce */
.<%= Entypo.css_prefix %>-inbox:before { content: '\e777'; } /* e777 */
.<%= Entypo.css_prefix %>-reply:before { content: '\e712'; } /* e712 */
.<%= Entypo.css_prefix %>-reply-all:before { content: '\e713'; } /* e713 */
.<%= Entypo.css_prefix %>-forward:before { content: '\27a6'; } /* 27a6 */
.<%= Entypo.css_prefix %>-user:before { content: '\1f464'; } /* 1f464 */
.<%= Entypo.css_prefix %>-users:before { content: '\1f465'; } /* 1f465 */
.<%= Entypo.css_prefix %>-add-user:before { content: '\e700'; } /* e700 */
.<%= Entypo.css_prefix %>-vcard:before { content: '\e722'; } /* e722 */
.<%= Entypo.css_prefix %>-export:before { content: '\e715'; } /* e715 */
.<%= Entypo.css_prefix %>-location:before { content: '\e724'; } /* e724 */
.<%= Entypo.css_prefix %>-map:before { content: '\e727'; } /* e727 */
.<%= Entypo.css_prefix %>-compass:before { content: '\e728'; } /* e728 */
.<%= Entypo.css_prefix %>-direction:before { content: '\27a2'; } /* 27a2 */
.<%= Entypo.css_prefix %>-share:before { content: '\e73c'; } /* e73c */
.<%= Entypo.css_prefix %>-shareable:before { content: '\e73e'; } /* e73e */
.<%= Entypo.css_prefix %>-heart:before { content: '\2665'; } /* 2665 */
.<%= Entypo.css_prefix %>-heart-empty:before { content: '\2661'; } /* 2661 */
.<%= Entypo.css_prefix %>-star:before { content: '\2605'; } /* 2605 */
.<%= Entypo.css_prefix %>-star-empty:before { content: '\2606'; } /* 2606 */
.<%= Entypo.css_prefix %>-thumbs-up:before { content: '\1f44d'; } /* 1f44d */
.<%= Entypo.css_prefix %>-thumbs-down:before { content: '\1f44e'; } /* 1f44e */
.<%= Entypo.css_prefix %>-chat:before { content: '\e720'; } /* e720 */
.<%= Entypo.css_prefix %>-comment:before { content: '\e718'; } /* e718 */
.<%= Entypo.css_prefix %>-quote:before { content: '\275e'; } /* 275e */
.<%= Entypo.css_prefix %>-home:before { content: '\2302'; } /* 2302 */
.<%= Entypo.css_prefix %>-popup:before { content: '\e74c'; } /* e74c */
.<%= Entypo.css_prefix %>-search:before { content: '\1f50d'; } /* 1f50d */
.<%= Entypo.css_prefix %>-flashlight:before { content: '\1f526'; } /* 1f526 */
.<%= Entypo.css_prefix %>-print:before { content: '\e716'; } /* e716 */
.<%= Entypo.css_prefix %>-bell:before { content: '\1f514'; } /* 1f514 */
.<%= Entypo.css_prefix %>-link:before { content: '\1f517'; } /* 1f517 */
.<%= Entypo.css_prefix %>-flag:before { content: '\2691'; } /* 2691 */
.<%= Entypo.css_prefix %>-cog:before { content: '\2699'; } /* 2699 */
.<%= Entypo.css_prefix %>-tools:before { content: '\2692'; } /* 2692 */
.<%= Entypo.css_prefix %>-trophy:before { content: '\1f3c6'; } /* 1f3c6 */
.<%= Entypo.css_prefix %>-tag:before { content: '\e70c'; } /* e70c */
.<%= Entypo.css_prefix %>-camera:before { content: '\1f4f7'; } /* 1f4f7 */
.<%= Entypo.css_prefix %>-megaphone:before { content: '\1f4e3'; } /* 1f4e3 */
.<%= Entypo.css_prefix %>-moon:before { content: '\263d'; } /* 263d */
.<%= Entypo.css_prefix %>-palette:before { content: '\1f3a8'; } /* 1f3a8 */
.<%= Entypo.css_prefix %>-leaf:before { content: '\1f342 '; } /* 1f342 */
.<%= Entypo.css_prefix %>-note:before { content: '\266a'; } /* 266a */
.<%= Entypo.css_prefix %>-beamed-note:before { content: '\266b'; } /* 266b */
.<%= Entypo.css_prefix %>-graduation-cap:before { content: '\1f393 '; } /* 1f393 */
.<%= Entypo.css_prefix %>-book:before { content: '\1f4d5 '; } /* 1f4d5 */
.<%= Entypo.css_prefix %>-newspaper:before { content: '\1f4f0'; } /* 1f4f0 */
.<%= Entypo.css_prefix %>-bag:before { content: '\1f45c'; } /* 1f45c */
.<%= Entypo.css_prefix %>-lifebuoy:before { content: '\e788'; } /* e788 */
.<%= Entypo.css_prefix %>-eye:before { content: '\e70a'; } /* e70a */
.<%= Entypo.css_prefix %>-clock:before { content: '\1f554'; } /* 1f554 */
.<%= Entypo.css_prefix %>-mic:before { content: '\1f3a4'; } /* 1f3a4 */
.<%= Entypo.css_prefix %>-calendar:before { content: '\1f4c5'; } /* 1f4c5 */
.<%= Entypo.css_prefix %>-flash:before { content: '\26a1'; } /* 26a1 */
.<%= Entypo.css_prefix %>-thunder-cloud:before { content: '\26c8'; } /* 26c8 */
.<%= Entypo.css_prefix %>-droplet:before { content: '\1f4a7'; } /* 1f4a7 */
.<%= Entypo.css_prefix %>-cd:before { content: '\1f4bf'; } /* 1f4bf */
.<%= Entypo.css_prefix %>-briefcase:before { content: '\1f4bc'; } /* 1f4bc */
.<%= Entypo.css_prefix %>-air:before { content: '\e753'; } /* e753 */
.<%= Entypo.css_prefix %>-hourglass:before { content: '\23f3'; } /* 23f3 */
.<%= Entypo.css_prefix %>-gauge:before { content: '\e7a2'; } /* e7a2 */
.<%= Entypo.css_prefix %>-language:before { content: '\e752'; } /* e752 */
.<%= Entypo.css_prefix %>-network:before { content: '\e776'; } /* e776 */
.<%= Entypo.css_prefix %>-key:before { content: '\1f511'; } /* 1f511 */
.<%= Entypo.css_prefix %>-battery:before { content: '\1f50b'; } /* 1f50b */
.<%= Entypo.css_prefix %>-bucket:before { content: '\e756'; } /* e756 */
.<%= Entypo.css_prefix %>-magnet:before { content: '\e7a1'; } /* e7a1 */
.<%= Entypo.css_prefix %>-drive:before { content: '\e755'; } /* e755 */
.<%= Entypo.css_prefix %>-cup:before { content: '\2615'; } /* 2615 */
.<%= Entypo.css_prefix %>-rocket:before { content: '\1f680'; } /* 1f680 */
.<%= Entypo.css_prefix %>-brush:before { content: '\e79a'; } /* e79a */
.<%= Entypo.css_prefix %>-suitcase:before { content: '\e78e'; } /* e78e */
.<%= Entypo.css_prefix %>-traffic-cone:before { content: '\e7a3'; } /* e7a3 */
.<%= Entypo.css_prefix %>-globe:before { content: '\1f30e'; } /* 1f30e */
.<%= Entypo.css_prefix %>-keyboard:before { content: '\2328'; } /* 2328 */
.<%= Entypo.css_prefix %>-publish:before { content: '\e74d'; } /* e74d */
.<%= Entypo.css_prefix %>-progress-3:before { content: '\e76b'; } /* e76b */
.<%= Entypo.css_prefix %>-progress-2:before { content: '\e76a'; } /* e76a */
.<%= Entypo.css_prefix %>-progress-1:before { content: '\e769'; } /* e769 */
.<%= Entypo.css_prefix %>-progress-0:before { content: '\e768'; } /* e768 */
.<%= Entypo.css_prefix %>-light-down:before { content: '\1f505'; } /* 1f505' */
.<%= Entypo.css_prefix %>-light-up:before { content: '\1f506'; } /* 1f506 */
.<%= Entypo.css_prefix %>-adjust:before { content: '\25d1'; } /* 25d1 */
.<%= Entypo.css_prefix %>-code:before { content: '\e714'; } /* e714 */
.<%= Entypo.css_prefix %>-monitor:before { content: '\1f4bb'; } /* 1f4bb */
.<%= Entypo.css_prefix %>-infinity:before { content: '\221e'; } /* 221e */
.<%= Entypo.css_prefix %>-credit-card:before { content: '\1f4b3'; } /* 1f4b3 */
.<%= Entypo.css_prefix %>-database:before { content: '\e754'; } /* e754 */
.<%= Entypo.css_prefix %>-clipboard:before { content: '\1f4cb'; } /* 1f4cb */
.<%= Entypo.css_prefix %>-box:before { content: '\1f4e6'; } /* 1f4e6 */
.<%= Entypo.css_prefix %>-ticket:before { content: '\1f3ab'; } /* 1f3ab */
.<%= Entypo.css_prefix %>-rss:before { content: '\e73a'; } /* e73a */
.<%= Entypo.css_prefix %>-signal:before { content: '\1f4f6'; } /* 1f4f6 */
.<%= Entypo.css_prefix %>-thermometer:before { content: '\e757'; } /* e757 */
.<%= Entypo.css_prefix %>-water:before { content: '\1f4a6'; } /* 1f4a6 */
.<%= Entypo.css_prefix %>-sweden:before { content: '\f601'; } /* f601 */
.<%= Entypo.css_prefix %>-lock:before { content: '\1f512'; } /* 1f512 */
.<%= Entypo.css_prefix %>-lock-open:before { content: '\1f513'; } /* 1f513 */
.<%= Entypo.css_prefix %>-logout:before { content: '\e741'; } /* e741 */
.<%= Entypo.css_prefix %>-login:before { content: '\e740'; } /* e740 */
.<%= Entypo.css_prefix %>-check:before { content: '\2713'; } /* 2713 */
.<%= Entypo.css_prefix %>-squared-plus:before { content: '\229e'; } /* 229e */
.<%= Entypo.css_prefix %>-squared-minus:before { content: '\229f'; } /* 229f */
.<%= Entypo.css_prefix %>-circled-plus:before { content: '\2795'; } /* 2795 */
.<%= Entypo.css_prefix %>-circled-minus:before { content: '\2796'; } /* 2796 */
.<%= Entypo.css_prefix %>-plus:before { content: '\2b'; } /* 2b */
.<%= Entypo.css_prefix %>-minus:before { content: '\2d'; } /* 2d */
.<%= Entypo.css_prefix %>-erase:before { content: '\232b'; } /* 232b */
.<%= Entypo.css_prefix %>-block:before { content: '\1f6ab'; } /* 1f6ab */
.<%= Entypo.css_prefix %>-info:before { content: '\2139'; } /* 2139 */
.<%= Entypo.css_prefix %>-circled-info:before { content: '\e705'; } /* e705 */
.<%= Entypo.css_prefix %>-help:before { content: '\2753'; } /* 2753 */
.<%= Entypo.css_prefix %>-circled-help:before { content: '\e704'; } /* e704 */
.<%= Entypo.css_prefix %>-ccw:before { content: '\27f2'; } /* 27f2 */
.<%= Entypo.css_prefix %>-cw:before { content: '\27f3'; } /* 27f3 */
.<%= Entypo.css_prefix %>-shuffle:before { content: '\1f500'; } /* 1f500 */
.<%= Entypo.css_prefix %>-back:before { content: '\1f519'; } /* 1f519 */
.<%= Entypo.css_prefix %>-level-up:before { content: '\21b0'; } /* 21b0 */
.<%= Entypo.css_prefix %>-level-down:before { content: '\21b3'; } /* 21b3 */
.<%= Entypo.css_prefix %>-retweet:before { content: '\e717'; } /* e717 */
.<%= Entypo.css_prefix %>-reshare:before { content: '\e717'; } /* e717 */
.<%= Entypo.css_prefix %>-loop:before { content: '\1f501'; } /* 1f501 */
.<%= Entypo.css_prefix %>-back-in-time:before { content: '\e771'; } /* e771 */
.<%= Entypo.css_prefix %>-switch:before { content: '\21c6'; } /* 21c6 */
.<%= Entypo.css_prefix %>-layout:before { content: '\268f'; } /* 268f */
.<%= Entypo.css_prefix %>-list:before { content: '\2630'; } /* 2630 */
.<%= Entypo.css_prefix %>-doc:before { content: '\e730'; } /* e730 */
.<%= Entypo.css_prefix %>-docs:before { content: '\e736'; } /* e736 */
.<%= Entypo.css_prefix %>-text-doc-inverted:before { content: '\e731'; } /* e731 */
.<%= Entypo.css_prefix %>-landscape-doc:before { content: '\e737'; } /* e737 */
.<%= Entypo.css_prefix %>-picture:before { content: '\1f304'; } /* 1f304 */
.<%= Entypo.css_prefix %>-video:before { content: '\1f3ac'; } /* 1f3ac */
.<%= Entypo.css_prefix %>-music:before { content: '\1f3b5'; } /* 1f3b5 */
.<%= Entypo.css_prefix %>-folder:before { content: '\1f4c1 '; } /* 1f4c1 */
.<%= Entypo.css_prefix %>-archive:before { content: '\e738'; } /* e738 */
.<%= Entypo.css_prefix %>-trash:before { content: '\e729'; } /* e729 */
.<%= Entypo.css_prefix %>-upload:before { content: '\1f4e4'; } /* 1f4e4 */
.<%= Entypo.css_prefix %>-download:before { content: '\1f4e5'; } /* 1f4e5 */
.<%= Entypo.css_prefix %>-install:before { content: '\e778'; } /* e778 */
.<%= Entypo.css_prefix %>-cloud:before { content: '\2601'; } /* 2601 */
.<%= Entypo.css_prefix %>-upload-cloud:before { content: '\e711'; } /* e711 */
.<%= Entypo.css_prefix %>-bookmark:before { content: '\1f516'; } /* 1f516 */
.<%= Entypo.css_prefix %>-bookmarks:before { content: '\1f4d1'; } /* 1f4d1 */
.<%= Entypo.css_prefix %>-play:before { content: '\25b6'; } /* 25b6 */
.<%= Entypo.css_prefix %>-paus:before { content: '\2389'; } /* 2389 */
.<%= Entypo.css_prefix %>-record:before { content: '\26ab'; } /* 26ab */
.<%= Entypo.css_prefix %>-stop:before { content: '\25a0'; } /* 25a0 */
.<%= Entypo.css_prefix %>-to-end:before { content: '\23ed'; } /* 23ed */
.<%= Entypo.css_prefix %>-to-start:before { content: '\23ee'; } /* 23ee */
.<%= Entypo.css_prefix %>-resize-full:before { content: '\e744'; } /* e744 */
.<%= Entypo.css_prefix %>-resize-small:before { content: '\e746'; } /* e746 */
.<%= Entypo.css_prefix %>-volume:before { content: '\e742'; } /* e742 */
.<%= Entypo.css_prefix %>-sound:before { content: '\1f50a'; } /* 1f50a */
.<%= Entypo.css_prefix %>-mute:before { content: '\1f507'; } /* 1f507 */
.<%= Entypo.css_prefix %>-flow-cascade:before { content: '\e790'; } /* e790 */
.<%= Entypo.css_prefix %>-flow-branch:before { content: '\e791'; } /* e791 */
.<%= Entypo.css_prefix %>-flow-tree:before { content: '\e792'; } /* e792 */
.<%= Entypo.css_prefix %>-flow-line:before { content: '\e793'; } /* e793 */
.<%= Entypo.css_prefix %>-flow-parallel:before { content: '\e794'; } /* e794 */
.<%= Entypo.css_prefix %>-left-bold:before { content: '\e4ad'; } /* e4ad */
.<%= Entypo.css_prefix %>-right-bold:before { content: '\e4ae'; } /* e4ae */
.<%= Entypo.css_prefix %>-up-bold:before { content: '\e4af'; } /* e4af */
.<%= Entypo.css_prefix %>-down-bold:before { content: '\e4b0'; } /* e4b0 */
.<%= Entypo.css_prefix %>-left:before { content: '\261c'; } /* 261c */
.<%= Entypo.css_prefix %>-up:before { content: '\261d'; } /* 261d */
.<%= Entypo.css_prefix %>-right:before { content: '\261e'; } /* 261e */
.<%= Entypo.css_prefix %>-down:before { content: '\261f'; } /* 261f */
.<%= Entypo.css_prefix %>-circled-down:before { content: '\e758'; } /* e758 */
.<%= Entypo.css_prefix %>-circled-left:before { content: '\e759'; } /* e759 */
.<%= Entypo.css_prefix %>-circled-right:before { content: '\e75a'; } /* e75a */
.<%= Entypo.css_prefix %>-circled-up:before { content: '\e75b'; } /* e75b */
.<%= Entypo.css_prefix %>-left-thin:before { content: '\2190'; } /* 2190 */
.<%= Entypo.css_prefix %>-up-thin:before { content: '\2191'; } /* 2191 */
.<%= Entypo.css_prefix %>-right-thin:before { content: '\2192'; } /* 2192 */
.<%= Entypo.css_prefix %>-down-thin:before { content: '\2193'; } /* 2193 */
.<%= Entypo.css_prefix %>-arrow-combo:before { content: '\e74f'; } /* e74f */
.<%= Entypo.css_prefix %>-dot:before { content: '\e78b'; } /* e78b */
.<%= Entypo.css_prefix %>-two-dots:before { content: '\e78c'; } /* e78c */
.<%= Entypo.css_prefix %>-three-dots:before { content: '\e78d'; } /* e78d */
.<%= Entypo.css_prefix %>-cc:before { content: '\e7a5'; } /* e7a5 */
.<%= Entypo.css_prefix %>-cc-by:before { content: '\e7a6'; } /* e7a6 */
.<%= Entypo.css_prefix %>-cc-nc:before { content: '\e7a7'; } /* e7a7 */
.<%= Entypo.css_prefix %>-cc-nc-eu:before { content: '\e7a8'; } /* e7a8 */
.<%= Entypo.css_prefix %>-cc-nc-jp:before { content: '\e7a9'; } /* e7a9 */
.<%= Entypo.css_prefix %>-cc-sa:before { content: '\e7aa'; } /* e7aa */
.<%= Entypo.css_prefix %>-cc-nd:before { content: '\e7ab'; } /* e7ab */
.<%= Entypo.css_prefix %>-cc-pd:before { content: '\e7ac'; } /* e7ac */
.<%= Entypo.css_prefix %>-cc-zero:before { content: '\e7ad'; } /* e7ad */
.<%= Entypo.css_prefix %>-cc-share:before { content: '\e7ae'; } /* e7ae */
.<%= Entypo.css_prefix %>-cc-remix:before { content: '\e7af'; } /* e7af */
.<%= Entypo.css_prefix %>-db-logo:before { content: '\f603'; } /* f603 */
.<%= Entypo.css_prefix %>-db-shape:before { content: '\f600'; } /* f600 */
.<%= Entypo.css_prefix %>-save:before { content: '\1f4be'; } /* 1f4be */
.<%= Entypo.css_prefix %>-ff:before { content: '\23e9'; } /* 23e9 */
.<%= Entypo.css_prefix %>-fb:before { content: '\23ea'; } /* 23ea */
.<%= Entypo.css_prefix %>-pie-chart:before { content: '\e751'; } /* e751 */
.<%= Entypo.css_prefix %>-line-graph:before { content: '\1f4c8'; } /* 1f4c8 */
.<%= Entypo.css_prefix %>-bar-graph:before { content: '\1f4ca '; } /* 1f4ca */
.<%= Entypo.css_prefix %>-area-graph:before { content: '\1f53e'; } /* 1f53e */
.<%= Entypo.css_prefix %>-chevron-down:before { content: '\e75c'; } /* e75c */
.<%= Entypo.css_prefix %>-chevron-left:before { content: '\e75d'; } /* e75d */
.<%= Entypo.css_prefix %>-chevron-right:before { content: '\e75e'; } /* e75e */
.<%= Entypo.css_prefix %>-chevron-up:before { content: '\e75f'; } /* e75f */
.<%= Entypo.css_prefix %>-chevron-small-down:before { content: '\e760'; } /* e760 */
.<%= Entypo.css_prefix %>-chevron-small-left:before { content: '\e761'; } /* e761 */
.<%= Entypo.css_prefix %>-chevron-small-right:before { content: '\e762'; } /* e762 */
.<%= Entypo.css_prefix %>-chevron-small-up:before { content: '\e763'; } /* e763 */
.<%= Entypo.css_prefix %>-chevron-thin-down:before { content: '\e764'; } /* e764 */
.<%= Entypo.css_prefix %>-chevron-thin-left:before { content: '\e765'; } /* e765 */
.<%= Entypo.css_prefix %>-chevron-thin-right:before { content: '\e766'; } /* e766 */
.<%= Entypo.css_prefix %>-chevron-thin-up:before { content: '\e767'; } /* e767 */
.<%= Entypo.css_prefix %>-text-doc:before { content: '\1f4c4'; } /* 1f4c4 */
.<%= Entypo.css_prefix %>-open-book:before { content: '\1f4d6'; } /* 1f4d6 */
.<%= Entypo.css_prefix %>-voicemail:before { content: '\2707'; } /* 2707 */
.<%= Entypo.css_prefix %>-triangle-right:before { content: '\25b8'; } /* 25b8 */
.<%= Entypo.css_prefix %>-triangle-up:before { content: '\25b4'; } /* 25b4 */
.<%= Entypo.css_prefix %>-triangle-down:before { content: '\25be'; } /* 25be */
.<%= Entypo.css_prefix %>-triangle-left:before { content: '\25c2'; } /* 25c2 */
.<%= Entypo.css_prefix %>-airplane:before { content: '\2708'; } /* 2708 */
.<%= Entypo.css_prefix %>-light-bulb:before { content: '\1f4a1'; } /* 1f4a1 */
.<%= Entypo.css_prefix %>-add-to-list:before { content: '\e003'; } /* e003 */
.<%= Entypo.css_prefix %>-browser:before { content: '\e74e'; } /* e74e */
.<%= Entypo.css_prefix %>-cart:before { content: '\e73d'; } /* e73d */
.<%= Entypo.css_prefix %>-cross-hair:before { content: '\1f3af'; } /* 1f3af */
.<%= Entypo.css_prefix %>-squared-cross:before { content: '\274e'; } /* 274e */
.<%= Entypo.css_prefix %>-circled-cross:before { content: '\2716'; } /* 2716 */
.<%= Entypo.css_prefix %>-warning:before { content: '\26a0'; } /* 26a0 */
.<%= Entypo.css_prefix %>-cross:before { content: '\2715'; } /* 2715 */
.<%= Entypo.css_prefix %>-new:before { content: '\1f4a5'; } /* 1f4a5 */
.<%= Entypo.css_prefix %>-cycle:before { content: '\1f504'; } /* 1f504 */
.<%= Entypo.css_prefix %>-numbered-list:before { content: '\e005'; } /* e005 */
.<%= Entypo.css_prefix %>-right-1:before { content: '\27a1'; } /* 27a1 */
.<%= Entypo.css_prefix %>-left-1:before { content: '\2b05'; } /* 2b05 */
.<%= Entypo.css_prefix %>-up-1:before { content: '\2b06'; } /* 2b06 */
.<%= Entypo.css_prefix %>-down-1:before { content: '\2b07'; } /* 2b07 */

/* social extention map */
.<%= Entypo.css_prefix %>-social-github:before { content: '\f300'; } /* f300 */
.<%= Entypo.css_prefix %>-social-social-c-github:before { content: '\f301'; } /* f301 */
.<%= Entypo.css_prefix %>-social-flickr:before { content: '\f303'; } /* f303 */
.<%= Entypo.css_prefix %>-social-c-flickr:before { content: '\f304'; } /* f304 */
.<%= Entypo.css_prefix %>-social-vimeo:before { content: '\f306'; } /* f306 */
.<%= Entypo.css_prefix %>-social-c-vimeo:before { content: '\f307'; } /* f307 */
.<%= Entypo.css_prefix %>-social-twitter:before { content: '\f309'; } /* f309 */
.<%= Entypo.css_prefix %>-social-c-twitter:before { content: '\f30a'; } /* f30a */
.<%= Entypo.css_prefix %>-social-facebook:before { content: '\f30c'; } /* f30c */
.<%= Entypo.css_prefix %>-social-c-facebook:before { content: '\f30d'; } /* f30d */
.<%= Entypo.css_prefix %>-social-s-facebook:before { content: '\f30e'; } /* f30e */
.<%= Entypo.css_prefix %>-social-google-plus:before { content: '\f30f'; } /* f30f */
.<%= Entypo.css_prefix %>-social-c-google-plus:before { content: '\f310'; } /* f310 */
.<%= Entypo.css_prefix %>-social-pinterest:before { content: '\f312'; } /* f312 */
.<%= Entypo.css_prefix %>-social-c-pinterest:before { content: '\f313'; } /* f313 */
.<%= Entypo.css_prefix %>-social-tumblr:before { content: '\f315'; } /* f315 */
.<%= Entypo.css_prefix %>-social-c-tumblr:before { content: '\f316'; } /* f316 */
.<%= Entypo.css_prefix %>-social-linkedin:before { content: '\f318'; } /* f318 */
.<%= Entypo.css_prefix %>-social-c-linkedin:before { content: '\f319'; } /* f319 */
.<%= Entypo.css_prefix %>-social-dribbble:before { content: '\f31b'; } /* f31b */
.<%= Entypo.css_prefix %>-social-c-dribbble:before { content: '\f31c'; } /* f31c */
.<%= Entypo.css_prefix %>-social-stumbleupon:before { content: '\f31e'; } /* f31e */
.<%= Entypo.css_prefix %>-social-c-stumbleupon:before { content: '\f31f'; } /* f31f */
.<%= Entypo.css_prefix %>-social-lastfm:before { content: '\f321'; } /* f321 */
.<%= Entypo.css_prefix %>-social-c-lastfm:before { content: '\f322'; } /* f322 */
.<%= Entypo.css_prefix %>-social-rdio:before { content: '\f324'; } /* f324 */
.<%= Entypo.css_prefix %>-social-c-rdio:before { content: '\f325'; } /* f325 */
.<%= Entypo.css_prefix %>-social-spotify:before { content: '\f327'; } /* f327 */
.<%= Entypo.css_prefix %>-social-c-spotify:before { content: '\f328'; } /* f328 */
.<%= Entypo.css_prefix %>-social-qq:before { content: '\f32a'; } /* f32a */
.<%= Entypo.css_prefix %>-social-instagram:before { content: '\f32d'; } /* f32d */
.<%= Entypo.css_prefix %>-social-dropbox:before { content: '\f330'; } /* f330 */
.<%= Entypo.css_prefix %>-social-evernote:before { content: '\f333'; } /* f333 */
.<%= Entypo.css_prefix %>-social-flattr:before { content: '\f336'; } /* f336 */
.<%= Entypo.css_prefix %>-social-skype:before { content: '\f339'; } /* f339 */
.<%= Entypo.css_prefix %>-social-c-skype:before { content: '\f33a'; } /* f33a */
.<%= Entypo.css_prefix %>-social-renren:before { content: '\f33c'; } /* f33c */
.<%= Entypo.css_prefix %>-social-sina-weibo:before { content: '\f33f'; } /* f33f */
.<%= Entypo.css_prefix %>-social-paypal:before { content: '\f342'; } /* f342 */
.<%= Entypo.css_prefix %>-social-picasa:before { content: '\f345'; } /* f345 */
.<%= Entypo.css_prefix %>-social-soundcloud:before { content: '\f348'; } /* f348 */
.<%= Entypo.css_prefix %>-social-mixi:before { content: '\f34b'; } /* f34b */
.<%= Entypo.css_prefix %>-social-behance:before { content: '\f34e'; } /* f34e */
.<%= Entypo.css_prefix %>-social-google-circles:before { content: '\f351'; } /* f351 */
.<%= Entypo.css_prefix %>-social-vk:before { content: '\f354'; } /* f354 */
.<%= Entypo.css_prefix %>-social-smashing:before { content: '\f357'; } /* f357 */
