@font-face {
  font-family: 'entypo';
  src: font-url('entypo.eot');
  src: font-url('entypo.eot?#iefix') format('embedded-opentype'),
       font-url('entypo.woff') format('woff'),
       font-url('entypo.ttf') format('truetype'),
       font-url('entypo.svg#entypo') format('svg');
  font-weight: normal; font-style: normal;
}
